==> tavern-1.0.1.tar.gz: test/tavern_test.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:tavern/src/tag_index.dart';
import 'package:tavern/src/tag_pages.dart';
import 'package:tavern/src/template.dart';
import 'package:tavern/src/template_cleanup.dart';
import 'package:test/test.dart';
import 'package:barback/barback.dart';
import 'package:tavern/src/metadata.dart';
import 'utils/test_case.dart';

main() {
  group('metadata transformer', () {
    test('extracts metadata', () async {
      // Load input file contents
      var path = 'test/fixtures/metadata.md';
      var file = new File(path);
      var contents = file.readAsStringSync();

      // Create input asset
      var assets = {new AssetId('a', 'web/foo.md'): contents};

      // Run barback
      var t = new TestCase([new Metadata()], assets);
      var barback = await t.run();

      // Check the metadata file contents
      var id = new AssetId('a', 'web/foo.metadata.json');
      var asset = await barback.getAssetById(id);
      var json = JSON.decode(await asset.readAsString());
      expect(json, containsPair('foo', 'bar'));
    });
  });
  group('template', () {
    test('applies mustache templates', () async {
      // Create the template
      var templateContents = '<div id="content">{{{content}}}</div>';
      var templateId = new AssetId('a', 'web/templates/mytemplate.html');

      // Create the page
      var fileContents = '<p>hello</p>';
      var fileId = new AssetId('a', 'web/mypage.html');

      var metadataContents = JSON.encode({'template': 'mytemplate'});
      var metadataId = new AssetId('a', 'web/mypage.metadata.json');

      var assets = {
        templateId: templateContents,
        fileId: fileContents,
        metadataId: metadataContents,
      };

      // Run barback
      var t = new TestCase([new Template(), new TemplateCleanup()], assets);
      var barback = await t.run();

      // Verify the template was not outputted
      var allAssets = await barback.getAllAssets();
      expect(allAssets, hasLength(2));

      // Check the output file contents
      var id = new AssetId('a', 'web/mypage.html');
      var asset = await barback.getAssetById(id);
      var contents = await asset.readAsString();
      expect(contents, contains('<div id="content"><p>hello</p></div>'));
    });
  });

  group('tag index', () {
    test('renders a tag index using a tag_index.html template', () async {
      // Create a page
      var metadataContents = JSON.encode({
        'tags': ['foo', 'bar']
      });
      var metadataId = new AssetId('a', 'web/mypage.metadata.json');

      var tagIndexContents = '<div>'
          '{{#tags}}'
          '<li><a href="{{url}}">{{name}}</a></li>'
          '{{/tags}}'
          '</div>';

      var tagIndexId = new AssetId('a', 'web/templates/tag_index.html');

      var assets = {
        metadataId: metadataContents,
        tagIndexId: tagIndexContents,
      };

      // Run barback
      var t = new TestCase([new TagIndex()], assets);
      var barback = await t.run();

      // Check the output file contents
      var id = new AssetId('a', 'web/tags/index.html');
      var asset = await barback.getAssetById(id);
      var contents = await asset.readAsString();
      var expected = '<li><a href="/tags/foo.html">foo</a></li>';
      expect(contents, contains(expected));
    });

    test('skips if no tag_index template is provided', () async {
      // Create a page
      var metadataContents = JSON.encode({
        'tags': ['foo', 'bar']
      });
      var metadataId = new AssetId('a', 'web/mypage.metadata.json');

      var assets = {
        metadataId: metadataContents,
      };

      // Run barback
      var t = new TestCase([new TagIndex()], assets);
      var barback = await t.run();

      // Check the output file contents
      var outputAssets = await barback.getAllAssets();
      expect(outputAssets, hasLength(1));
    });
  });
  group('TagPages', () {
      test('skips if no tag_index template is provided', () async {
        // Create a page
        var metadataContents = JSON.encode({
          'tags': ['foo', 'bar']
        });
        var metadataId = new AssetId('a', 'web/mypage.metadata.json');

        var assets = {
          metadataId: metadataContents,
        };

        // Run barback
        var t = new TestCase([new TagPages()], assets);
        var barback = await t.run();

        // Check the output file contents
        var id = new AssetId('a', 'web/tags/index.html');
        var outputAssets = await barback.getAllAssets();
        expect(outputAssets, hasLength(1));
      });
  });
}

==> tavern-1.0.2.tar.gz: test/tavern_test.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:tavern/src/settings.dart';
import 'package:tavern/src/sitemap.dart';
import 'package:tavern/src/tag_index.dart';
import 'package:tavern/src/tag_pages.dart';
import 'package:tavern/src/template.dart';
import 'package:tavern/src/template_cleanup.dart';
import 'package:test/test.dart';
import 'package:barback/barback.dart';
import 'package:tavern/src/metadata.dart';
import 'utils/test_case.dart';

main() {
  group('metadata transformer', () {
    test('extracts metadata', () async {
      // Load input file contents
      var path = 'test/fixtures/metadata.md';
      var file = new File(path);
      var contents = file.readAsStringSync();

      // Create input asset
      var assets = {new AssetId('a', 'web/foo.md'): contents};

      // Run barback
      var t = new TestCase([new Metadata()], assets);
      var barback = await t.run();

      // Check the metadata file contents
      var id = new AssetId('a', 'web/foo.metadata.json');
      var asset = await barback.getAssetById(id);
      var json = JSON.decode(await asset.readAsString());
      expect(json, containsPair('foo', 'bar'));
    });
  });
  group('template', () {
    test('applies mustache templates', () async {
      // Create the template
      var templateContents = '<div id="content">{{{content}}}</div>';
      var templateId = new AssetId('a', 'web/templates/mytemplate.html');

      // Create the page
      var fileContents = '<p>hello</p>';
      var fileId = new AssetId('a', 'web/mypage.html');

      var metadataContents = JSON.encode({'template': 'mytemplate'});
      var metadataId = new AssetId('a', 'web/mypage.metadata.json');

      var assets = {
        templateId: templateContents,
        fileId: fileContents,
        metadataId: metadataContents,
      };

      // Run barback
      var t = new TestCase([new Template(), new TemplateCleanup()], assets);
      var barback = await t.run();

      // Verify the template was not outputted
      var allAssets = await barback.getAllAssets();
      expect(allAssets, hasLength(2));

      // Check the output file contents
      var id = new AssetId('a', 'web/mypage.html');
      var asset = await barback.getAssetById(id);
      var contents = await asset.readAsString();
      expect(contents, contains('<div id="content"><p>hello</p></div>'));
    });
  });

  group('tag index', () {
    test('renders a tag index using a tag_index.html template', () async {
      // Create a page
      var metadataContents = JSON.encode({
        'tags': ['foo', 'bar']
      });
      var metadataId = new AssetId('a', 'web/mypage.metadata.json');

      var tagIndexContents = '<div>'
          '{{#tags}}'
          '<li><a href="{{url}}">{{name}}</a></li>'
          '{{/tags}}'
          '</div>';

      var tagIndexId = new AssetId('a', 'web/templates/tag_index.html');

      var assets = {
        metadataId: metadataContents,
        tagIndexId: tagIndexContents,
      };

      var settings = new TavernSettings();

      // Run barback
      var t = new TestCase([new TagIndex(settings)], assets);
      var barback = await t.run();

      // Check the output file contents
      var id = new AssetId('a', 'web/tags/index.html');
      var asset = await barback.getAssetById(id);
      var contents = await asset.readAsString();
      var expected = '<li><a href="/tags/foo.html">foo</a></li>';
      expect(contents, contains(expected));
    });

    test('skips if no tag_index template is provided', () async {
      // Create a page
      var metadataContents = JSON.encode({
        'tags': ['foo', 'bar']
      });
      var metadataId = new AssetId('a', 'web/mypage.metadata.json');

      var assets = {
        metadataId: metadataContents,
      };

      var settings = new TavernSettings();

      // Run barback
      var t = new TestCase([new TagIndex(settings)], assets);
      var barback = await t.run();

      // Check the output file contents
      var outputAssets = await barback.getAllAssets();
      expect(outputAssets, hasLength(1));
    });
  });

  group('TagPages', () {
    test('skips if no tag_index template is provided', () async {
      // Create a page
      var metadataContents = JSON.encode({
        'tags': ['foo', 'bar']
      });
      var metadataId = new AssetId('a', 'web/mypage.metadata.json');

      var assets = {
        metadataId: metadataContents,
      };

      var settings = new TavernSettings();

      // Run barback
      var t = new TestCase([new TagPages(settings)], assets);
      var barback = await t.run();

      // Check the output file contents
      var outputAssets = await barback.getAllAssets();
      expect(outputAssets, hasLength(1));
    });

    test('generates tag pages', () async {
      // Create a page
      var metadataContents = JSON.encode({
        'tags': ['foo', 'bar'],
        'url': '/mypage.html'
      });
      var metadataId = new AssetId('a', 'web/mypage.metadata.json');

      var tagIndexContents = '<div>'
          '{{#tags}}'
          '<li><a href="{{url}}">{{name}}</a></li>'
          '{{/tags}}'
          '</div>';

      var tagIndexId = new AssetId('a', 'web/templates/tag_index.html');

      var tagPageContents = '<h1>Posts Tagged {{tag}}</h1>'
          '<div id="content">'
          '<ul>'
          '{{#posts}}'
          '<li><a href="{{url}}">{{name}}</a></li>'
          '{{/posts}}'
          '</ul>'
          '</div>';

      var tagPageId = new AssetId('a', 'web/templates/tag_page.html');

      var assets = {
        metadataId: metadataContents,
        tagIndexId: tagIndexContents,
        tagPageId: tagPageContents,
      };

      var settings = new TavernSettings(siteUrl: 'http://foo.com', sitemapPath: '/sitemap.xml');

      // Run barback
      var t = new TestCase(
          [new TagIndex(settings), new TagPages(settings)], assets);
      var barback = await t.run();

      // Check the output file contents
      var outputAssets = await barback.getAllAssets();
      expect(outputAssets, hasLength(6));

      // Verify the tag page was created.
      var tagPage = outputAssets
          .firstWhere((asset) => asset.id.path == "web/tags/foo.html");
      var expected = '<h1>Posts Tagged foo</h1>'
          '<div id="content">'
          '<ul><li><a href="&#x2F;mypage.html"></a></li></ul>'
          '</div>';
      expect(await tagPage.readAsString(), equals(expected));
      expect(tagPage, isNotNull);
    });
  });

  group('Sitemap', () {
    test('generates sitemap.xml based on settings', () async {
      // Create a page
      var indexContents = '''<html></html>''';
      var indexId = new AssetId('a', 'web/index.html');

      var assets = {
        indexId: indexContents,
      };

      var settings = new TavernSettings(siteUrl: 'http://foo.com', sitemapPath: 'sitemap.xml');

      // Run barback
      var t = new TestCase([new Sitemap(settings)], assets);
      var barback = await t.run();

      // Check the output file contents
      var id = new AssetId('a', 'web/sitemap.xml');
      var asset = await barback.getAssetById(id);
      var contents = await asset.readAsString();
      expect(contents, isNotEmpty);

      // Load expected file contents
      var path = 'test/fixtures/sitemap.xml';
      var file = new File(path);
      var expected = file.readAsStringSync();

      expect(contents, equals(expected));
    });
  });

  group('TagPageUrlGenerator', () {

    test('stripIndexHtml: false', () {
      var generator = new TagPageUrlGenerator('/tags/{{tag}}.html');
      var result = generator.getUrl('hello');
      expect(result, equals('/tags/hello.html'));
    });
    test('stripIndexHtml: true', () {
      var generator = new TagPageUrlGenerator('/tags/{{tag}}.html');
      var result = generator.getUrl('index', stripIndexHtml: true);
      expect(result, equals('/tags/'));
    });
    test('stripIndexHtml: true with no index', () {
      var generator = new TagPageUrlGenerator('/tags/{{tag}}.html');
      var result = generator.getUrl('hello', stripIndexHtml: true);
      expect(result, equals('/tags/hello.html'));
    });
  });
}
